from bs4 import BeautifulSoup

try:
    from urlparse import urljoin
except ImportError:
    from urllib.parse import urljoin

from pyoembed.exceptions import ProviderException
from pyoembed.providers import BaseProvider
from pyoembed import get_http_client


class AutoDiscoverProvider(BaseProvider):

    priority = 99999999  # should be the last, always.

    # following properties are not used because we are overriding all the
    # methods that used them.
    oembed_endpoint = None
    oembed_schemas = None

    def url_supported(self, url):
        return True  # autodiscover supports anything :)

    async def oembed_url(self, url):
        client = get_http_client()
        response = await client.get(url)

        if not response.status == 200:
            raise ProviderException('Failed to auto-discover oEmbed provider '
                                    'for url: %s' % url)
        text = await response.text()
        bs = BeautifulSoup(text, 'lxml')

        # we prefer json over xml, so let's try it first :)
        oembed_url = bs.find('link', type='application/json+oembed', href=True)

        # if json isn't available, try xml
        if oembed_url is None:
            oembed_url = bs.find('link', type='text/xml+oembed', href=True)

        if oembed_url is None:
            raise ProviderException('No oEmbed url found: %s' % url)

        return urljoin(url, oembed_url['href'])
